BunchShaderConfig class

Constructors

BunchShaderConfig({required List<Type> shaders, String output = 'shaders', String? name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
output → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shaders → List<Type>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited