ShaderBody class

Constructors

ShaderBody({List<String> inputs = const [], List<String> samplers = const [], List<String> process = const [], List<String> others = const []})
ShaderBody.fromSource(String body)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputs → List<String>
final
others → List<String>
final
process → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplers → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited